==> moodle-5.1.zip: moodle/public/lang/en/customfield.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'core_customfield', language 'en'
 *
 * @package   core
 * @copyright 2018 Toni Barbera  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['action'] = 'Action';
$string['addingnewcustomfield'] = 'Adding a new {$a}';
$string['addnewcategory'] = 'Add a new category';
$string['afterfield'] = 'After field {$a}';
$string['categorynotfound'] = 'Category not found';
$string['checked'] = 'Checked';
$string['commonsettings'] = 'General';
$string['componentsettings'] = 'Component settings';
$string['confirmdeletecategory'] = 'Are you sure you want to delete this category? All fields inside the category will also be deleted and all data associated with them. This action cannot be undone.';
$string['confirmdeletefield'] = 'Are you sure you want to delete this field and all associated data? This action cannot be undone.';
$string['createnewcustomfield'] = 'Add a new custom field';
$string['customfield'] = 'Custom field';
$string['customfielddata'] = 'Custom fields data';
$string['customfields'] = 'Custom fields';
$string['defaultvalue'] = 'Default value';
$string['description'] = 'Description';
$string['description_help'] = 'The description is displayed in the form below the field.';
$string['edit'] = 'Edit';
$string['editcategoryname'] = 'Edit category name';
$string['editingfield'] = 'Updating {$a}';
$string['errorfieldtypenotfound'] = 'Field type {$a} not found';
$string['erroruniquevalues'] = 'This value is already used.';
$string['eventcategorycreated'] = 'Custom field category created';
$string['eventcategorydeleted'] = 'Custom field category deleted';
$string['eventcategoryupdated'] = 'Custom field category updated';
$string['eventfieldcreated'] = 'Custom field created';
$string['eventfielddeleted'] = 'Custom field deleted';
$string['eventfieldupdated'] = 'Custom field updated';
$string['eventsharedcategoryusagedisabled'] = 'Shared category usage disabled';
$string['eventsharedcategoryusageenabled'] = 'Shared category usage enabled';
$string['fieldname'] = 'Name';
$string['fieldnotfound'] = 'Field not found';
$string['fieldshortname'] = 'Short name';
$string['formfieldcheckshortname'] = 'Short name already exists';
$string['invalidshortnameerror'] = 'The short name can only contain alphanumeric lowercase characters and underscores (_).';
$string['isdataunique'] = 'Unique data';
$string['isdataunique_help'] = 'This setting determines whether the value entered must be unique and not entered previously.';
$string['isfieldrequired'] = 'Required';
$string['isfieldrequired_help'] = 'A required field is a field that must be filled in with value before submission of the form.';
$string['link'] = 'Link';
$string['linktarget'] = 'Link target';
$string['modify'] = 'Modify';
$string['movecategory'] = 'Move "{$a}"';
$string['movefield'] = 'Move "{$a}"';
$string['no'] = 'No';
$string['nocategories'] = 'There are no custom fields and categories.';
$string['nopermissionconfigure'] = 'You don\'t have permission to configure fields here.';
$string['notchecked'] = 'Not checked';
$string['otherfields'] = 'Other fields';
$string['otherfieldsn'] = 'Other fields {$a}';
$string['privacy:metadata:customfield_data'] = 'Represents custom field data saved to a context';
$string['privacy:metadata:customfield_data:charvalue'] = 'Data value when it is a character';
$string['privacy:metadata:customfield_data:contextid'] = 'The ID of the context where the data was saved';
$string['privacy:metadata:customfield_data:decvalue'] = 'Data value, when it is a decimal ';
$string['privacy:metadata:customfield_data:fieldid'] = 'Field definition ID';
$string['privacy:metadata:customfield_data:instanceid'] = 'Instance ID related to the data';
$string['privacy:metadata:customfield_data:intvalue'] = 'Data value, when it is an integer';
$string['privacy:metadata:customfield_data:shortcharvalue'] = 'Data value when it is a short character';
$string['privacy:metadata:customfield_data:timecreated'] = 'Time when data was created';
$string['privacy:metadata:customfield_data:timemodified'] = 'Time when data was last modified';
$string['privacy:metadata:customfield_data:value'] = 'Data value, when it is a text';
$string['privacy:metadata:customfield_data:valueformat'] = 'The format of the value, when it is a text';
$string['privacy:metadata:customfield_data:valuetrust'] = 'The trust flag of the value, when it is text';
$string['privacy:metadata:customfield_shared'] = 'Represents custom field shared saved to a context';
$string['privacy:metadata:customfield_shared:area'] = 'The area the shared field is associated with';
$string['privacy:metadata:customfield_shared:categoryid'] = 'The ID of the category the shared field belongs to';
$string['privacy:metadata:customfield_shared:component'] = 'The component the shared field is associated with';
$string['privacy:metadata:customfield_shared:itemid'] = 'The ID of the item the shared field is associated with';
$string['privacy:metadata:customfieldpluginsummary'] = 'Fields for various components';
$string['privacy:metadata:filepurpose'] = 'File attached to the custom field data';
$string['sharedcategoryhelptext'] = 'When enabled, the custom fields in this category will be used';
$string['sharedcustomfields'] = 'Shared custom fields';
$string['shortname'] = 'Short name';
$string['shortname_help'] = 'The short name must be unique and can only contain alphanumeric lowercase characters and underscores (_). It is not displayed anywhere on the site, but may be used for synchronisation with external systems or in web services.';
$string['showdate'] = 'Show date';
$string['specificsettings'] = 'Specific settings';
$string['therearenofields'] = 'There are no fields in this category';
$string['totopofcategory'] = 'To the top of category {$a}';
$string['type'] = 'Type';
$string['unknownhandler'] = 'Unable to find handler for custom fields for component {$a->component} and area {$a->area}.';
$string['yes'] = 'Yes';

==> moodle-5.1.1.zip: moodle/public/lang/en/customfield.php <==
<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Strings for component 'core_customfield', language 'en'
 *
 * @package   core
 * @copyright 2018 Toni Barbera  {@link http://moodle.com}
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

$string['action'] = 'Action';
$string['addingnewcustomfield'] = 'Adding a new {$a}';
$string['addnewcategory'] = 'Add a new category';
$string['afterfield'] = 'After field {$a}';
$string['categorynotfound'] = 'Category not found';
$string['checked'] = 'Checked';
$string['commonsettings'] = 'General';
$string['componentsettings'] = 'Component settings';
$string['confirmdeletecategory'] = 'Are you sure you want to delete this category? All fields inside the category will also be deleted and all data associated with them. This action cannot be undone.';
$string['confirmdeletefield'] = 'Are you sure you want to delete this field and all associated data? This action cannot be undone.';
$string['createnewcustomfield'] = 'Add a new custom field';
$string['customfield'] = 'Custom field';
$string['customfielddata'] = 'Custom fields data';
$string['customfields'] = 'Custom fields';
$string['defaultvalue'] = 'Default value';
$string['deletecategory'] = 'Delete custom field category: {$a}';
$string['deletefield'] = 'Delete custom field: {$a}';
$string['description'] = 'Description';
$string['description_help'] = 'The description is displayed in the form below the field.';
$string['edit'] = 'Edit';
$string['editcategoryname'] = 'Edit category name';
$string['editfield'] = 'Edit custom field: {$a}';
$string['editingfield'] = 'Updating {$a}';
$string['errorfieldtypenotfound'] = 'Field type {$a} not found';
$string['erroruniquevalues'] = 'This value is already used.';
$string['eventcategorycreated'] = 'Custom field category created';
$string['eventcategorydeleted'] = 'Custom field category deleted';
$string['eventcategoryupdated'] = 'Custom field category updated';
$string['eventfieldcreated'] = 'Custom field created';
$string['eventfielddeleted'] = 'Custom field deleted';
$string['eventfieldupdated'] = 'Custom field updated';
$string['eventsharedcategoryusagedisabled'] = 'Shared category usage disabled';
$string['eventsharedcategoryusageenabled'] = 'Shared category usage enabled';
$string['fieldname'] = 'Name';
$string['fieldnotfound'] = 'Field not found';
$string['fieldshortname'] = 'Short name';
$string['formfieldcheckshortname'] = 'Short name already exists';
$string['invalidshortnameerror'] = 'The short name can only contain alphanumeric lowercase characters and underscores (_).';
$string['isdataunique'] = 'Unique data';
$string['isdataunique_help'] = 'This setting determines whether the value entered must be unique and not entered previously.';
$string['isfieldrequired'] = 'Required';
$string['isfieldrequired_help'] = 'A required field is a field that must be filled in with value before submission of the form.';
$string['link'] = 'Link';
$string['linktarget'] = 'Link target';
$string['modify'] = 'Modify';
$string['movecategory'] = 'Move "{$a}"';
$string['movefield'] = 'Move "{$a}"';
$string['no'] = 'No';
$string['nocategories'] = 'There are no custom fields and categories.';
$string['nopermissionconfigure'] = 'You don\'t have permission to configure fields here.';
$string['notchecked'] = 'Not checked';
$string['otherfields'] = 'Other fields';
$string['otherfieldsn'] = 'Other fields {$a}';
$string['privacy:metadata:customfield_data'] = 'Represents custom field data saved to a context';
$string['privacy:metadata:customfield_data:charvalue'] = 'Data value when it is a character';
$string['privacy:metadata:customfield_data:contextid'] = 'The ID of the context where the data was saved';
$string['privacy:metadata:customfield_data:decvalue'] = 'Data value, when it is a decimal ';
$string['privacy:metadata:customfield_data:fieldid'] = 'Field definition ID';
$string['privacy:metadata:customfield_data:instanceid'] = 'Instance ID related to the data';
$string['privacy:metadata:customfield_data:intvalue'] = 'Data value, when it is an integer';
$string['privacy:metadata:customfield_data:shortcharvalue'] = 'Data value when it is a short character';
$string['privacy:metadata:customfield_data:timecreated'] = 'Time when data was created';
$string['privacy:metadata:customfield_data:timemodified'] = 'Time when data was last modified';
$string['privacy:metadata:customfield_data:value'] = 'Data value, when it is a text';
$string['privacy:metadata:customfield_data:valueformat'] = 'The format of the value, when it is a text';
$string['privacy:metadata:customfield_data:valuetrust'] = 'The trust flag of the value, when it is text';
$string['privacy:metadata:customfield_shared'] = 'Represents custom field shared saved to a context';
$string['privacy:metadata:customfield_shared:area'] = 'The area the shared field is associated with';
$string['privacy:metadata:customfield_shared:categoryid'] = 'The ID of the category the shared field belongs to';
$string['privacy:metadata:customfield_shared:component'] = 'The component the shared field is associated with';
$string['privacy:metadata:customfield_shared:itemid'] = 'The ID of the item the shared field is associated with';
$string['privacy:metadata:customfieldpluginsummary'] = 'Fields for various components';
$string['privacy:metadata:filepurpose'] = 'File attached to the custom field data';
$string['sharedcategoryhelptext'] = 'When enabled, the custom fields in this category will be used';
$string['sharedcustomfields'] = 'Shared custom fields';
$string['shortname'] = 'Short name';
$string['shortname_help'] = 'The short name must be unique and can only contain alphanumeric lowercase characters and underscores (_). It is not displayed anywhere on the site, but may be used for synchronisation with external systems or in web services.';
$string['showdate'] = 'Show date';
$string['specificsettings'] = 'Specific settings';
$string['therearenofields'] = 'There are no fields in this category';
$string['totopofcategory'] = 'To the top of category {$a}';
$string['type'] = 'Type';
$string['unknownhandler'] = 'Unable to find handler for custom fields for component {$a->component} and area {$a->area}.';
$string['yes'] = 'Yes';
